local ui = {}
local vars = dofile'vars.lua'

local options_box = iup.vbox{} --contains toggle controls
local options = {
	{
		key='IsAutoLoad',
		ctrl=iup.stationtoggle{title='Auto-Load'},
		help='This enables auto-loading of items when a manufacturing mission is accepted as well as when the active mission removes the items (more than one load needed)',
	},{
		key='IsAutoUnload',
		ctrl=iup.stationtoggle{title='Auto-Unload'},
		help='This enables auto-unloading of all items when a manufacturing mission completes (only if MfgAide was used to load items)',
	},{
		key='IsOneWarning',
		ctrl=iup.stationtoggle{title='One Warning per Mission'},
		help='If enabled the warning message will not be shown more than once per manufacturing mission',
	},{
		key='IsLoadOnWarning',
		ctrl=iup.stationtoggle{title='Load on Warning'},
		help='Even if not all the required items are present, it will still load the ones that are available (no items get auto-loaded on a warning regardless of this setting)',
	},{
		key='isLoadDestOnly',
		ctrl=iup.stationtoggle{title='Load at Destination Station Only'},
		help='The auto-loader will only load items while you are at the destination station',
	},
}

local help_text = 'MfgAide v'..MfgAide.version..'\n'..
[[MfgAide looks for items in your inventory that match the items needed for an active mission and loads them into your active ship. It will not search the cargo of other ships present, nor will it purchase the needed items.

To have it look for needed items and load them, use the command: ]]..'\127a0a0a0/mfg\127o'..[[

Items that take up the greatest volume will be loaded first to maximize loading efficiency. Items will not get loaded if they are already present in the active ship. When it searches for items to load, if not all of the required items are available then a warning message will be displayed.

For setting additional options, use the command: ]]..'\127a0a0a0/mfg options\127o\n'

for _,opt in ipairs(options) do
	if opt.key and opt.help then help_text = help_text..'\n\127ffff00'..opt.ctrl.title..'\127o - '..opt.help end --append help string for each toggle control
	
	if opt.ctrl then iup.Append(options_box, opt.ctrl) end --create vbox with toggle controls
end

function ui:ShowHelp()
	StationHelpDialog:Open(help_text)
end

local button_help = iup.stationbutton{title="Help", hotkey=iup.K_h, action=ui.ShowHelp}
local button_ok = iup.stationbutton{title="OK"}

local frame = iup.vbox{
	iup.hbox{iup.fill{}, iup.label{title="MfgAide v"..MfgAide.version,font=Font.H3}, iup.fill{}},
	iup.fill{size=10},
	iup.hbox{iup.fill{size=12}, options_box, iup.fill{}, gap=8},
	iup.fill{size=8},
	iup.hbox{button_help, iup.fill{}, button_ok, gap=8},
	alignment="ACENTER",
}

-- Create Dialog --

ui.dialog = iup.dialog{
	iup.vbox{
		iup.fill{},
		iup.hbox{
			iup.fill{},
			iup.stationhighopacityframe{
				iup.stationhighopacityframebg{
					frame,
					expand="NO",
					gap=8,
				},
			},
			iup.fill{},
		},
		iup.fill{},
	},
	BGCOLOR = "0 0 0 160 *",
	FULLSCREEN="YES",
	RESIZE="NO",
	BORDER="NO",
	MENUBOX="YES",
	TOPMOST="YES",
	DEFAULTESC=button_ok,
	DEFAULTENTER=button_ok,
}
ui.dialog:map()

function ui:Show()
	ui.Update(self) --reset control values in case of changed by console

	ShowDialog(ui.dialog,iup.CENTER,iup.CENTER)
	iup.Refresh(ui.dialog)
end

--capture state of controls and save to config
function ui:Hide()
	for _,opt in ipairs(options) do
		if opt.ctrl and opt.key then
			local value = opt.ctrl.value=="ON"
			vars.SaveVars(opt.key, value)
		end
	end
	
	HideDialog(ui.dialog)
end

--Set all control values to config values
function ui:Update()
	for _,opt in ipairs(options) do
		if opt.ctrl and opt.key then opt.ctrl.value = vars.GetVars(opt.key) and "ON" or "OFF" end
	end
end

function button_ok.action() ui.Hide(button_ok) end

return ui, vars